@@ -1,6 +1,5 @@
-import os, sys
+import os
 import argparse
-import json
 import re
 from datetime import datetime
 import logging
@@ -13,10 +12,11 @@ from ..deploy.compose_conv import convert_compose_to_vars
 from ..deploy.kube import prep_ustate_kube_versions
 from ..deploy.unity import update_unity_ios_creds
 from ..buildinfo.info import GitChanges
+from ..deploy.string import slugify
+
 
 def get_jira_name_from_branch(branch_name):
-    regexp = '(feature|bugfix)?(?P<name>\w+-\d+)'
-    match = re.search(regexp, branch_name)
+    match = re.search(r'(feature|bugfix)?(?P<name>\w+-\d+)', branch_name)
     if match:
         return match.groupdict()['name']
 
@@ -50,10 +50,10 @@ def create_and_build_from_prs():
     bb = BitBucket(os.getenv('BB_CLIENT'), os.getenv('BB_TOKEN'), 'neurohive')
     uc = UnityCloud(os.getenv('UNITY_ORG_ID', 'unity_oekd8fheerjomw'), project_name=args.unity_project)
 
-    # # удаляю прошлые сборки )
+    # удаляю прошлые сборки )
     logging.basicConfig(level=logging.INFO)
     uc.remove_target_with_prefix('AutoPR')
-    #получаю список веток с открытими prs
+    # получаю список веток с открытими prs
     opened_prs = bb._get_opened_pr(args.git_project)
     branches = [branch['source']['branch']['name'] for branch in opened_prs]
     build_targets = create_uc_builds_from_branches(uc, branches, args.src_build_target_name)
@@ -125,3 +125,10 @@ def get_git_changelog():
     args = parser.parse_args()
     gc = GitChanges(os.getcwd(), args.base_branch, args.table)
     print(gc.show_changes())
+
+
+def slugify_cmd():
+    parser = argparse.ArgumentParser()
+    parser.add_argument("--string", type=str, required=True)
+    args = parser.parse_args()
+    print(slugify(args.string))
