@@ -48,7 +48,8 @@ class AwsEcsDeploy:
         return json.dumps(appspec)
 
     def prep_task_from_settings_dir(self):
-        settings_path = os.path.abspath(self.def_dir)
+        # NOTE Seems unused, to removal
+        # settings_path = os.path.abspath(self.def_dir)
         self._init_terraform()
         self._apply_terraform()
 
