@@ -1,7 +1,6 @@
 from collections import namedtuple
 import os
 import base64
-import json
 import logging
 from datetime import datetime
 import io
@@ -16,7 +15,6 @@ from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import serialization
 
 
-
 class AppStoreConnectException(Exception):
     pass
 
@@ -112,7 +110,10 @@ class AppStoreConnect:
             # get bundle id info
             resp = requests.get(profile['relationships']['bundleId']['links']['related'], headers=self._prep_headers())
             if resp.json()['data']['attributes']['identifier'] == bundle_id:
-                resp = requests.get(profile['relationships']['certificates']['links']['related'], headers=self._prep_headers())
+                resp = requests.get(
+                    profile['relationships']['certificates']['links']['related'],
+                    headers=self._prep_headers()
+                )
                 bundle = Bundle(
                     cert_name=resp.json()['data'][0]['attributes']['name'],
                     cert_data=base64.b64decode(resp.json()['data'][0]['attributes']['certificateContent']),
@@ -131,10 +132,10 @@ class AppStoreConnect:
         provision_stream = io.BytesIO(bundle.prov_data)
         certificate = x509.load_der_x509_certificate(certificate_stream.read(), default_backend())
         private_key = serialization.load_pem_private_key(
-                private_key_stream.read(),
-                password=None,
-                backend=default_backend()
-            )
+            private_key_stream.read(),
+            password=None,
+            backend=default_backend()
+        )
 
         pkcs12 = OpenSSL.crypto.PKCS12()
         pkcs12.set_certificate(OpenSSL.crypto.X509.from_cryptography(certificate))
