@@ -1,5 +1,4 @@
 import json
-import os
 import time
 import logging
 import tempfile
@@ -10,6 +9,7 @@ import boto3
 
 logging.basicConfig(level=logging.INFO)
 
+
 class LegacyServerCleanerException(Exception):
     pass
 
@@ -26,7 +26,10 @@ class LegacyServiceCleaner:
         for action in rule["Actions"]:
             if action.get("Type") == "forward":
                 targets_list_size = len(action["ForwardConfig"]["TargetGroups"])
-                if targets_list_size == 1 and action["ForwardConfig"]["TargetGroups"][0]['TargetGroupArn'] == target_group_arn:
+                if (
+                    targets_list_size == 1
+                    and action["ForwardConfig"]["TargetGroups"][0]['TargetGroupArn'] == target_group_arn
+                ):
                     remove_rule = True
         if remove_rule:
             logging.info(f'remove rule: {rule_arn}')
@@ -105,7 +108,8 @@ class LegacyServiceCleaner:
 
         for deploy in oldiest:
             logging.info(f"delete: {deploy['filename']}")
-            breakpoint()
+            # NOTE Guessing this is some debug trails and should be removed
+            breakpoint()  # noqa: F821
             self._del_old_deploy(deploy)
             self.remove_deploy_data(bucket, deploy)
 
@@ -116,7 +120,7 @@ class LegacyServiceCleaner:
         print(var_name, data_name)
         client = boto3.client('s3')
         for name in [var_name, data_name]:
-            response = client.delete_object(
+            response = client.delete_object(  # noqa: F841
                 Bucket=bucket,
                 Key=f'ecs/ustate/{name}'
             )
@@ -128,7 +132,6 @@ class LegacyServiceCleaner:
         td_data_dir = td_data_dir.joinpath(tf_data_fn)
         item['state_data'] = json.loads(td_data_dir.read_text())['outputs']
 
-
         rule_arn = item['data']['rule_arn']
         target_group_arn = item['data']['target_group_arn']
         sd_id = item['state_data']['aws_service_discovery_service']['value']
@@ -152,7 +155,7 @@ class LegacyServiceCleaner:
         items_vers = {}
         for item in items:
             version = int(item['data']['lib_version'])
-            if not version in items_vers:
+            if version not in items_vers:
                 items_vers[version] = list()
             items_vers[version].append(item)
         keep_part = sorted(items_vers.keys(), reverse=True)[:4]
@@ -227,7 +230,7 @@ class LegacyServiceCleaner:
 
 if __name__ == '__main__':
     lc = LegacyServiceCleaner()
-    # rule_arn = 'arn:aws:elasticloadbalancing:eu-west-1:265052334192:listener-rule/app/mib-testing/3c289b6855ce644f/73c26b32828676db/323719583e371926'
+    # rule_arn = 'arn:aws:elasticloadbalancing:eu-west-1:265052334192:listener-rule/app/mib-testing/3c289b6855ce644f/73c26b32828676db/323719583e371926'  # noqa: E501
     # tg = 'arn:aws:elasticloadbalancing:eu-west-1:265052334192:targetgroup/ustate-78-799/ac2e741fc54228d2'
     # lc.remove_target_group_from_rule(rule_arn, tg)
     lc.cleanup_deploys()
