@@ -1,4 +1,5 @@
-import os, sys
+import os
+import sys
 import logging
 import argparse
 
@@ -35,5 +36,3 @@ def main():
     except Exception as e:
         logger.error("Unable to comment jira task")
         logger.error(e)
-
-
