@@ -1,6 +1,5 @@
 import os
 from datetime import datetime
-import json
 import logging
 import argparse
 from copy import deepcopy
@@ -95,7 +94,8 @@ class UnityCloud:
         new_target_settings.pop('links')
         new_build_target = self._create_build_target(new_target_settings)
         return new_build_target
-        #self._create_build(new_build_target['buildtargetid'])
+        # NOTE Definitely unused, to removal
+        # self._create_build(new_build_target['buildtargetid'])
 
     def _create_build_target(self, target_data):
         url = f'{self.base_url}/orgs/{self.org_id}/projects/{self.project_id}/buildtargets'
@@ -125,9 +125,7 @@ class UnityCloud:
 
     def _create_build(self, build_target_id):
         url = f'{self.base_url}/orgs/{self.org_id}/projects/{self.project_id}/buildtargets/{build_target_id}/builds'
-        data = {
-          "clean": True,
-        }
+        data = {"clean": True}
         resp = requests.post(url, json=data, headers=self.auth_headers)
         if resp.status_code == 202:
             return resp.json()
@@ -145,7 +143,7 @@ class UnityCloud:
 
     def _get_target_id(self, target_name):
         return [bt for bt in self.build_targets if bt['name'] == target_name][0]["buildtargetid"]
-        
+
     def _set_targets(self):
         url = f'{self.base_url}/orgs/{self.org_id}/projects/{self.project_id}/buildtargets'
         req = requests.get(url, headers=self.auth_headers)
